/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id$ */
package org.apache.xmlgraphics.image.loader.impl;

import org.junit.Test;
import static org.junit.Assert.assertEquals;

import org.apache.xmlgraphics.image.loader.MockImageContext;

public class DefaultImageSessionContextTestCase {

    @Test
    public void testDefaultResolution() {
        MockImageContext mock = new MockImageContext(false);
        DefaultImageSessionContext context = new DefaultImageSessionContext(mock, null);

        assertEquals("Resolution must come from the parent context",
                (int) mock.getSourceResolution(), (int) context.getSourceResolution());
    }
}

